@@ -1,17 +1,17 @@
 package Test::Mocha::Stub;
 {
-  $Test::Mocha::Stub::VERSION = '0.14';
+  $Test::Mocha::Stub::VERSION = '0.15';
 }
-# ABSTRACT: Create methods stubs for mock objects
+# ABSTRACT: Mock wrapper to create method stubs
 
 use strict;
 use warnings;
 
 use Carp qw( croak );
 use Test::Mocha::StubbedCall;
-use Test::Mocha::Types qw( Mock Slurpy );
-use Test::Mocha::Util qw( extract_method_name get_attribute_value );
-use Types::Standard qw( ArrayRef HashRef );
+use Test::Mocha::Types  qw( Mock Slurpy );
+use Test::Mocha::Util   qw( extract_method_name get_attribute_value );
+use Types::Standard     qw( ArrayRef HashRef );
 
 our $AUTOLOAD;
 
@@ -60,4 +60,7 @@ sub AUTOLOAD {
     return $stub;
 }
 
+# Don't let AUTOLOAD() handle DESTROY()
+sub DESTROY { }
+
 1;
